"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FirebaseFirestoreSnapshot = exports.FirebaseFirestoreCollection = exports.FirebaseFirestoreDocument = void 0;
const firestore_1 = require("firebase/firestore");
class FirebaseFirestoreDocument {
    options;
    path;
    constructor(options, path) {
        this.options = options;
        this.path = path;
    }
    get firestoreInstance() {
        const firestoreInstance = (0, firestore_1.getFirestore)(this.options.app);
        if (this.options.useFirestoreEmulatorPort !== null)
            (0, firestore_1.connectFirestoreEmulator)(firestoreInstance, '127.0.0.1', this.options.useFirestoreEmulatorPort);
        return firestoreInstance;
    }
    getSubCollection(key) {
        return new FirebaseFirestoreCollection(this.options, this.path.appending(key));
    }
    async setValues(values) {
        await (0, firestore_1.setDoc)((0, firestore_1.doc)(this.firestoreInstance, this.path.fullPath), values);
    }
    async snapshot() {
        const snapshot = await (0, firestore_1.getDoc)((0, firestore_1.doc)(this.firestoreInstance, this.path.fullPath));
        return new FirebaseFirestoreSnapshot(this.options, snapshot);
    }
}
exports.FirebaseFirestoreDocument = FirebaseFirestoreDocument;
class FirebaseFirestoreCollection {
    options;
    path;
    constructor(options, path) {
        this.options = options;
        this.path = path;
    }
    get firestoreInstance() {
        const firestoreInstance = (0, firestore_1.getFirestore)(this.options.app);
        if (this.options.useFirestoreEmulatorPort !== null)
            (0, firestore_1.connectFirestoreEmulator)(firestoreInstance, '127.0.0.1', this.options.useFirestoreEmulatorPort);
        return firestoreInstance;
    }
    async addDocument(key, documentValues) {
        await (0, firestore_1.setDoc)((0, firestore_1.doc)(this.firestoreInstance, this.path.appending(key).fullPath), documentValues);
    }
    getDocument(key) {
        return new FirebaseFirestoreDocument(this.options, this.path.appending(key));
    }
    async removeDocument(key) {
        await (0, firestore_1.deleteDoc)((0, firestore_1.doc)(this.firestoreInstance, this.path.appending(key).fullPath));
    }
}
exports.FirebaseFirestoreCollection = FirebaseFirestoreCollection;
class FirebaseFirestoreSnapshot {
    options;
    snapshot;
    constructor(options, snapshot) {
        this.options = options;
        this.snapshot = snapshot;
    }
    get exists() {
        return this.snapshot.exists();
    }
    get data() {
        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
        return this.snapshot.data();
    }
}
exports.FirebaseFirestoreSnapshot = FirebaseFirestoreSnapshot;
